projectal.entities.project_template API documentation

# projectal.entities.project_template

View Source

     1from projectal import api
     2from projectal.entity import Entity
     3from projectal.linkers import *
     4
     5
     6class ProjectTemplate(Entity, NoteLinker, TagLinker):
     7    """
     8    Implementation of the
     9    [Project Template](https://projectal.com/docs/latest/#tag/Project-Template) API.
    10    """
    11
    12    _path = "template/project"
    13    _name = "project_template"
    14    _links = [NoteLinker, TagLinker]
    15
    16    @classmethod
    17    def autoschedule(cls, project, mode="ASAP"):
    18        """
    19        Autoschedule the project template.
    20
    21        `project`: A ProjectTemplate entity
    22
    23        `mode`: `ASAP` or `ALAP`
    24        """
    25        url = "/api/template/project/schedule?mode={}".format(mode)
    26        api.post(url, [project])
    27        return True

class ProjectTemplate(projectal.entity.Entity, projectal.linkers.NoteLinker, projectal.linkers.TagLinker): View Source

     7class ProjectTemplate(Entity, NoteLinker, TagLinker):
     8    """
     9    Implementation of the
    10    [Project Template](https://projectal.com/docs/latest/#tag/Project-Template) API.
    11    """
    12
    13    _path = "template/project"
    14    _name = "project_template"
    15    _links = [NoteLinker, TagLinker]
    16
    17    @classmethod
    18    def autoschedule(cls, project, mode="ASAP"):
    19        """
    20        Autoschedule the project template.
    21
    22        `project`: A ProjectTemplate entity
    23
    24        `mode`: `ASAP` or `ALAP`
    25        """
    26        url = "/api/template/project/schedule?mode={}".format(mode)
    27        api.post(url, [project])
    28        return True

Implementation of the Project Template API.

@classmethod
def autoschedule(cls, project, mode='ASAP'): View Source

    17    @classmethod
    18    def autoschedule(cls, project, mode="ASAP"):
    19        """
    20        Autoschedule the project template.
    21
    22        `project`: A ProjectTemplate entity
    23
    24        `mode`: `ASAP` or `ALAP`
    25        """
    26        url = "/api/template/project/schedule?mode={}".format(mode)
    27        api.post(url, [project])
    28        return True

Autoschedule the project template.

`project`: A ProjectTemplate entity

`mode`: `ASAP` or `ALAP`

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.TagLinker
  link_tag
  unlink_tag
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy